==============
Alert Exporter
==============


.. image:: https://img.shields.io/pypi/v/alert_exporter.svg
        :target: https://pypi.python.org/pypi/alert_exporter

.. image:: https://img.shields.io/travis/BapRx/alert_exporter.svg
        :target: https://travis-ci.com/BapRx/alert_exporter

.. image:: https://readthedocs.org/projects/alert-exporter/badge/?version=latest
        :target: https://alert-exporter.readthedocs.io/en/latest/?version=latest
        :alt: Documentation Status


.. image:: https://pyup.io/repos/github/BapRx/alert_exporter/shield.svg
     :target: https://pyup.io/repos/github/BapRx/alert_exporter/
     :alt: Updates



Extract a list of alerts configured in different sources (eg: Prometheus Rules, CloudWatch Alarms, etc.)


* Free software: GNU General Public License v3
* Documentation: https://alert-exporter.readthedocs.io.


Features
--------

* TODO

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
